searchData={"items":[{"type":"module","title":"Tmp","doc":"Temporary directories that are monitored and automatically removed.","ref":"Tmp.html"},{"type":"module","title":"Usage - Tmp","doc":"Define your Tmp module:\n\n    defmodule MyApp.Tmp do\n      use Tmp\n    end\n\nOr with a custom base directory:\n\n    defmodule MyApp.CustomTmp do\n      use Tmp, base_dir: \"/path/to/custom/base/dir\"\n    end\n\nAdd it to your supervision tree:\n\n    children = [\n      {MyApp.Tmp, name: MyApp.Tmp}\n    ]\n\nUse it in your code:\n\n    MyApp.Tmp.dir(fn tmp_dir_path ->\n      _my_file_path = Path.join(tmp_dir_path, \"my_file\")\n      # do work with my_file_path...\n      # then return a value\n      {:ok, :foobar}\n    end)\n\nYou can also override the base directory for a specific call:\n\n    MyApp.Tmp.dir(fn tmp_dir_path ->\n      # ...\n    end, base_dir: \"/path/to/another/base/dir\")","ref":"Tmp.html#module-usage"},{"type":"function","title":"Tmp.dir/3","doc":"Creates a temporary directory and passes the path to the given function.\n\n`function` runs in a new linked GenServer process.\nThe directory is automatically removed when the function returns or the\nprocess terminates.","ref":"Tmp.html#dir/3"},{"type":"function","title":"Options - Tmp.dir/3","doc":"* `:base_dir` - The directory where the temporary directory will be created.\n    Defaults to `System.tmp_dir()`. This directory serves as the parent\n    directory and won't be removed when the function returns. Only the\n    newly created temporary directory within `:base_dir` will be cleaned up.\n\n  * `:prefix` - A string to prefix the temporary directory name. This can be\n    useful for identifying the purpose or origin of the temporary directory.\n\n  * `:timeout` - How long the function is allowed to run before the\n    GenServer call terminates, defaults to :infinity","ref":"Tmp.html#dir/3-options"},{"type":"function","title":"Examples - Tmp.dir/3","doc":"MyApp.Tmp.dir(fn tmp_dir_path ->\n      :ok = Path.join(tmp_dir_path, \"my_new_file\") |> File.touch()\n      1 + 1\n    end)","ref":"Tmp.html#dir/3-examples"},{"type":"module","title":"Tmp.Monitor","doc":"Monitors `Tmp.Worker` processes and removes their associated temporary directories when the processes exit.\nIt is typically started as part of the Tmp supervision tree and should not be used directly.\n\nThis module is responsible for:\n- Keeping track of temporary directories created by `Tmp.Worker` processes\n- Monitoring these processes for termination\n- Automatically removing the associated temporary directories when the monitored processes exit\n- Cleaning up all monitored directories when the monitor itself terminates\n\nThe `Tmp.Worker` will automatically register directories with this monitor.","ref":"Tmp.Monitor.html"},{"type":"function","title":"Tmp.Monitor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Tmp.Monitor.html#child_spec/1"},{"type":"function","title":"Tmp.Monitor.monitor/3","doc":"","ref":"Tmp.Monitor.html#monitor/3"},{"type":"function","title":"Tmp.Monitor.start_link/1","doc":"","ref":"Tmp.Monitor.html#start_link/1"},{"type":"module","title":"Tmp.Worker","doc":"Executes the function given to `Tmp.dir/3` in a temporary GenServer process.\nThis module is not typically used directly.\n\nThis module is responsible for:\n- Creating a temporary directory\n- Ensuring the directory is monitored for cleanup","ref":"Tmp.Worker.html"},{"type":"function","title":"Tmp.Worker.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Tmp.Worker.html#child_spec/1"},{"type":"function","title":"Tmp.Worker.execute/4","doc":"","ref":"Tmp.Worker.html#execute/4"},{"type":"function","title":"Tmp.Worker.start_link/1","doc":"","ref":"Tmp.Worker.html#start_link/1"},{"type":"module","title":"Tmp.Worker.State","doc":"","ref":"Tmp.Worker.State.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}